@@ -33,12 +33,9 @@ class EncoderRNN(BaseRNN):
         embedded = self.embedding(input_var)
         embedded = self.input_dropout(embedded)
         
-        if self.variable_lengths:
-            try:
-                embedded = nn.utils.rnn.pack_padded_sequence(embedded, 
+        if self.variable_lengths:            
+            embedded = nn.utils.rnn.pack_padded_sequence(embedded, 
                                 input_lengths, batch_first=True)
-            except:
-                print(input_lengths)
         output, hidden = self.rnn(embedded)
         if self.variable_lengths:
             output, _ = nn.utils.rnn.pad_packed_sequence(output, batch_first=True)
